@@ -35,6 +35,8 @@
 #
 #-------------------------------------------------------------------------
 #END_LICENSE
+if( !isset($gCms) ) exit;
+$this->SetCurrentTab('defaultadmin');
 $message="";
 
 function handle_null_date_ts($val)
@@ -350,7 +352,6 @@ function calculate_recurring_events($event_start_ut, $event_end_ut,$event_recur_
   return $results;
 }
 
-if (!$this->AllowAccess()) return;
 $events_to_categories_table_name = $this->events_to_categories_table_name;
 if( isset($params['cancel']) ) $this->Redirect($id,'defaultadmin',$returnid,array("module_message"=>$message));
 
@@ -358,13 +359,30 @@ if( isset($params['cancel']) ) $this->Redirect($id,'defaultadmin',$returnid,arra
 // Gather parameters
 //
 $recurring_events = '';
-$user_id = $gCms->variables['user_id'] * -1 - 100;
+$user_id = get_userid(FALSE) * -1 - 100;
 $categories = get_parameter_value($params, 'event_categories',-1);
 $event['event_id'] = get_parameter_value($params, 'event_id', -1);
 $event = $this->GetEvent($event['event_id']);
 $this->GetEventFromParams($event,$params,true);
 $event_parent_id = $event['event_id'];
 
+// permissions check
+if( $event_id < 1 ) {
+  // adding
+  if( !$this->CheckPermission('Modify Calendar') && !$this->CheckPermission('Add Calendar Events') ) {
+    $this->SetError($this->Lang('error_permission'));
+    $this->RedirectToAdminTab();
+  }
+}
+else {
+  // editing
+  if( !$this->CheckPermission('Modify Calendar') && 
+      !($this->CheckPermission('Edit My Calendar Events') && $event['event_created_by'] == $user_id) ) {
+    $this->SetError($this->Lang('error_permission'));
+    $this->RedirectToAdminTab();
+  }
+}
+
 // Carry through any old values
 // just incase a new file was not uploaded
 foreach( $params as $k => $v ) {
@@ -688,7 +706,7 @@ $fieldtext = '';
     $field_value = get_parameter_value($params, 'field_' . $safefieldname, '');
       
     $sql = "INSERT INTO " . $this->event_field_values_table_name . " (field_name, event_id, field_value) VALUES (?,?,?)";
-      
+
     if ($field_value) $result=$db->Execute($sql,array($fieldname,$event['event_id'],$field_value));
       
     $customfieldsvalues[] = array($fieldname,$event['event_id'],$field_value);
