@@ -67,17 +67,14 @@ $types = $params['field_types'];
 if( isset($params['field_searchable']) ) $searchable = $params['field_searchable'];
 if( isset($params['field_wysiwyg']) ) $wysiwyg = $params['field_wysiwyg'];
 
-//debug_display($params); die();
-
 // find deletions.
 $fields = $this->GetFields();
 $field_names = cge_array::extract_field($fields,'field_name');
 $deleted = array();
 
-foreach( $field_names as $name ) {
+foreach( $field_ids as $name ) {
   if( $name == '' ) continue;
   if( !in_array($name,$names) ) {
-    debug_display('delete '.$name);
     _cgcalDeleteField($name);
     $ndeletes++;
   }
