@@ -38,40 +38,39 @@
 
 $display = get_parameter_value($params, 'display', 'calendar');
 
-switch($display)
-  {
-  case 'calendar':
-    require_once(dirname(__FILE__).'/function.displaycalendar.php');
-    break;
+switch($display) {
+ case 'calendar':
+   require(dirname(__FILE__).'/function.displaycalendar.php');
+   break;
 
-  case 'event':
-    require_once(dirname(__FILE__).'/function.displayevent.php');
-    break;
+ case 'event':
+   require(dirname(__FILE__).'/function.displayevent.php');
+   break;
 
-  case 'list':
-    require_once(dirname(__FILE__).'/function.displaylist.php');
-    break;
+ case 'list':
+   require(dirname(__FILE__).'/function.displaylist.php');
+   break;
 
-  case 'weeklist':
-    require_once(dirname(__FILE__).'/function.displayweeklist.php');
-    break;
+ case 'weeklist':
+   require(dirname(__FILE__).'/function.displayweeklist.php');
+   break;
 
-  case 'yearlist':
-    require_once(dirname(__FILE__).'/function.displayyearlist.php');
-    break;
+ case 'yearlist':
+   require(dirname(__FILE__).'/function.displayyearlist.php');
+   break;
 
-  case 'pastlist':
-    $params['pastitems'] = 1;
-    require_once(dirname(__FILE__).'/function.displayupcominglist.php');
-    break;
+ case 'pastlist':
+   $params['pastitems'] = 1;
+   require(dirname(__FILE__).'/function.displayupcominglist.php');
+   break;
 
-  case 'upcominglist':
-    require_once(dirname(__FILE__).'/function.displayupcominglist.php');
-    break;
+ case 'upcominglist':
+   require(dirname(__FILE__).'/function.displayupcominglist.php');
+   break;
 
-  default:
-    echo "Calendar: unknown display attribute '$display'!";
-    break;
-  }
+ default:
+   echo "Calendar: unknown display attribute '$display'!";
+   break;
+ }
 
 ?>
\ No newline at end of file
