@@ -54,7 +54,9 @@ $feu_uid = $feu->LoggedInId();
 $query = 'SELECT event_id FROM '.$this->events_table_name.' WHERE event_id = ? AND event_created_by = ?';
 $tmp = $db->GetOne($query,array((int)$params['event_id'],$feu_uid));
 
-if( $tmp == $params['event_id'] ) $this->AdminDeleteEvent($id,$params,$returnid);
+if( $tmp == $params['event_id'] ) {
+  $res = cgcalendar_utils::delete_event($tmp);
+}
 
 $this->RedirectContent($returnid);
 
