@@ -43,7 +43,7 @@ if( !$this->CheckPermission('Modify Calendar') &&
 $userid = null;
 if( !$this->CheckPermission('Modify Calendar') ) $userid = get_userid(FALSE) * -1 - 100;
 
-$bare_filter = array('showchildren'=>0,'keyword'=>'','category'=>-1,'filter_applied'=>0,'filter_date'=>'');
+$bare_filter = array('showchildren'=>0,'keyword'=>'','category'=>-1,'filter_applied'=>0,'filter_date'=>'','nodate'=>0);
 $filter = $bare_filter;
 $ser_filter = $this->session_get('filter');
 if( $ser_filter ) {
@@ -68,6 +68,7 @@ else if( isset($params['filter_submit']) ) {
   $filter['showchildren'] = (int)get_parameter_value($params,'filter_showchildren',0);
   $filter['keyword'] = trim(get_parameter_value($params,'filter_keyword',''));
   $filter['category'] = (int)get_parameter_value($params,'filter_category',0);
+  if( $filter['keyword'] ) $filter['nodate'] = 1;
   $this->session_put('filter',serialize($filter));
 }
 else if( isset($params['filter_reset']) ) {
@@ -110,13 +111,15 @@ if( $this->CheckPermission('Modify Calendar') || $this->CheckPermission('Add Cal
 }
 $smarty->assign('show_children', $this->CreateInputYesNoDropdown($id,'showchildren',$filter['showchildren']));
 
-$tmpdate = $filter['filter_date'];
-if( !$tmpdate ) $tmpdate = date('Y').'-'.date('m');
-list($year,$month) = explode('-',$tmpdate,2);
-$sdate = "$year-$month-01 00:00:00";
-$eday = date('t',strtotime("$year-$month-02"));
-$edate = "$year-$month-$eday 23:59:59";
-{
+$sdate = $edate = null;
+if( !$filter['nodate'] ) {
+  $tmpdate = $filter['filter_date'];
+  if( !$tmpdate ) $tmpdate = date('Y').'-'.date('m');
+  list($year,$month) = explode('-',$tmpdate,2);
+  $sdate = "$year-$month-01 00:00:00";
+  $eday = date('t',strtotime("$year-$month-02"));
+  $edate = "$year-$month-$eday 23:59:59";
+
   $t_year = $year;
   $t_month = $month - 1;
   if( $t_month < 1 ) {
@@ -139,8 +142,10 @@ $edate = "$year-$month-$eday 23:59:59";
 $sql = 'SELECT E.* FROM '.$this->events_table_name . ' E';
 $where = array();
 
-$where[] = "((E.event_date_start BETWEEN '{$sdate}' AND '{$edate}') OR (E.event_date_end BETWEEN '{$sdate}' AND '{$edate}'))";
-$sql = 'SELECT E.* FROM '. $this->events_table_name . " E";
+if( $sdate && $edate ) {
+  $where[] = "((E.event_date_start BETWEEN '{$sdate}' AND '{$edate}') OR (E.event_date_end BETWEEN '{$sdate}' AND '{$edate}'))";
+  $sql = 'SELECT E.* FROM '. $this->events_table_name . " E";
+}
 
 if( !is_null($userid) ) {
   $where[] = "E.event_created_by = {$userid}";
