@@ -89,7 +89,7 @@ $sorting = ($reverse == 'true' ? 'DESC' : 'ASC');
 $start = $db->DbTimeStamp(time());
 if( isset($params['displayforday']) ) $start = $db->DbTimeStamp(mktime(00,00,30));
 
-$txt = "WHERE (E.event_date_start $expr $start) OR (E.event_date_end $expr $start AND COALESCE(E.event_date_end,'****') != '****')";
+$txt = "WHERE (E.event_date_start $expr $start OR (E.event_date_end $expr $start AND COALESCE(E.event_date_end,'****') != '****'))";
 if ($pastitems) {
   $txt = "WHERE ( (E.event_date_start $expr $start AND COALESCE(E.event_date_end,'****') = '****' ) OR
                   (E.event_date_end $expr $start AND COALESCE(E.event_date_end,'****') != '****' ) )";
