@@ -1,6 +1,8 @@
 <?php
 # Simple Language file for the Calendar module.
 # Copyright (c) 2004 by Rob Allen <rob@akrabat.com>
+$lang['info_cal_filter_by'] = 'When searching <em>(filtering)</em> by words in the title, date scrolling is not available';
+$lang['msg_nodates'] = 'Title search applied';
 $lang['title_recurring_event'] = 'This is a recurring event with children';
 $lang['title_child_event'] = 'This is a recurrance of a parent event';
 $lang['error_somedeleted'] = 'Some of the events were deleted.  However, due to permissions some were not';
@@ -411,7 +413,7 @@ $lang['cal_past_events'] = 'Past Events';
 $lang['cal_upcoming_events'] = 'Upcoming Events';
 $lang['cal_any_category'] = 'Any Category';
 $lang['cal_show_only_events_in'] = 'Show Only Events In';
-$lang['cal_filter_by'] = 'Filter Title By <em>(regex)</em>';
+$lang['cal_filter_by'] = 'Search Title <em>(regex)</em>';
 $lang['cal_go'] = 'Go';
 $lang['cal_title'] = 'Title';
 $lang['cal_fromdate'] = 'From Date';
