@@ -325,196 +325,4 @@ $lang['cal_recur_until'] = 'Gentages indtil';
 $lang['help_template'] = '<p><b>Print Author Name:</b></p>
 <code>Author: {$event.authorname}</code>
 ';
-$lang['cal_help'] = '<h3>Notice:</h3>
-<p>Version 1.0 of the Calendar module broke backward compatibility with previous versions.  Upgrading a previous installation of Calendar to this version is not possible.</p>
-<h3>What does this do?</h3>
-<p>Calendar is a module for displaying events on your page. When the
-module is installed, a Calendar admin page is added to the plugins menu
-that will allow you to manage your events.</p>
-<h3>Security</h3>
-<p>The user must belong to a group with the &#039;Modify Calendar&#039; permission
-in order to add, edit, or delete calendar event entries.</p>
-<h3>How do I use it?</h3>
-<ol>
-  <li>Put the cms_module tag in the page content. Make sure it is not enclosed in &amp;lt;pre&amp;gt;...&amp;lt;/pre&amp;gt; tags.  You will need to view source code for this.  The code would look something like:<br />
-  <tt>{cms_module module=&quot;CGCalendar&quot;}</tt><br />
-  <li>Style the calendar appropriately for your display (an example stylesheet is provided for this purpose)</li>
-</ol>
-<br/>
-<p><b>To attach the sample stylesheet to your template:</b></p>
-<ol>
-<li>Go to &quot;Layout -> Templates&quot;</li>
-<li>Click the CSS icon (Attach Stylesheet to Template) button to the right of your template</li>
-<li>Choose &quot;Calendar CSS example&quot; from the drop-down menu.</li>
-<li>Click the &quot;Add a Stylesheet&quot; button.</li>
-</ol>
-<br/>
-<h3>Parameters</h3>
-<table border=0 cellpadding=3 cellspacing=0>
-  <tr>
-     <td>display</td>
-     <td>Acceptable values:<br>
-	 &quot;calendar&quot; - displays events for the current month in a traditional grid.  Inclues links to prev. and next months.<br>
-	 &quot;list&quot; - displays events for the current month as a list.  Includes links to prev. and next months.<br>
-	 &quot;yearlist&quot; - displays events for the current year in a list.  Includes links to prev. and next years.<br>
-	 &quot;pastlist&quot; - displays all past events.  No prev/next links.<br/>
-	 &quot;upcominglist&quot; - displays all upcoming events.  No prev/next links.<br>
-		Defaults to &quot;calendar&quot; <em>(optional)</em>
-     </td>
-  </tr>
-
-  <tr>
-     <td>category</td>
-     <td>Only display items for that category. Leaving unset, will show all categories. Note that
-	 you can limit to muliple categories by separating each one with a comma.<em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>month</td>
-     <td>Display entries for a particular month. If year is not set, then the current year is
-	 assumed. This option only works if display is set to &quot;list&quot; or &quot;calendar&quot;. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>year</td>
-     <td>Display entries for a particular year.
-	This option only works if display is set to &quot;list&quot; or &quot;calendar&quot;. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>limit</td>
-     <td>Set to the maximum number of events to display. This option only works if display is set to &quot;list&quot;, &quot;pastlist&quot; or &quot;upcominglist&quot;. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>first_day_of_week</td>
-     <td>Set to the first day of the week as a number between 0 and 6 (0 = Sunday). Default is 1 (Monday).
-	 This option only works if display is set to &quot;calendar&quot;. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>summaries</td>
-     <td>Set to 1 to display the summary information or 0 to not display it in calendar mode. Default is 1. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>detail</td>
-     <td>Set to 1 to display the detail information or 0 to not display it in list mode. Default is 0. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>use_session</td>
-     <td>Use a session variable to store the current month of the calendar. Default is true. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>compact_view</td>
-     <td>Set to 1 to hide the navigation links. Helpful to show current month&#039;s events on the home page. Default is 0. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>inline</td>
-     <td>Set to 0 to set all of the event links to inlined mode (they will replace the page content).  Default is 1. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>reverse</td>
-     <td>Set to true to display events in reverse chronological order. Applicable to list, pastlist and upcominglist displays. Default is false. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>detailpage=&quot;pagealias&quot;</td>
-     <td>Page to display Calendar event details in. This can either be a page alias or an id. Used to allow details to be displayed in a different template from the summary. Default is current page. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>columns</td>
-     <td>Makes Calendar output only a subset of relevant events for allowing displaying in columns. Allowed values 1/2. Default is 1. Implemented for upcominglist and pastlist only. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>columnstyle</td>
-     <td>If columns=2 this parameter sets whether the order of events in columns should be organized horizontally (0) or vertically (1). Default is 1. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>currentcolumn</td>
-     <td>If columns=2 this indicated whether Calendar should display content of column 1 or 2. Allowed values 1/2. Default is 1. <em>(optional)</em></td>
-  </tr>
-
-  <tr>
-     <td>event_id</td>
-     <td>Used with the display=event mode, this parameter allows you to display information about a specific event on demand.</td>
-  </tr>
-
-  <tr>
-     <td>limit</td>
-     <td>Used with the list displays, this parameter allows specifying a maximum number of events to display, and then provides pagination capabilities.</td>
-  </tr>
-
-  <tr>
-     <td>calendartemplate</td>
-     <td>Used with display=calendar, this parameter allows you to specify a non default calendar template.</td>
-  </tr>
-
-  <tr>
-     <td>eventtemplate</td>
-     <td>Used with display=event, or you can also specify this parameter on any Calendar module call, this parameter allows you to specify a non default event template.</td>
-  </tr>
-
-  <tr>
-     <td>listtemplate</td>
-     <td>Used with display=list, this parameter allows you to specify a non default list template.</td>
-  </tr>
-
-  <tr>
-     <td>upcominglisttemplate</td>
-     <td>Used with display=upcominglist, this parameter allows you to specify a non default upcominglist template.</td>
-  </tr>
-
-  <tr>
-     <td>moretext</td>
-     <td>Used in the various summary templates, this parameter allows specifying different text for the link to the event detail display.</td>
-  </tr>
-</table>
-
-<h3>Custom Fields</h3>
-<p>It is possible to define a number of custom fields to associate with each event using the Fields tab in the admin. Once one or more fields has been defined the values of that field for each event can be set using the events tab in the admin. These field values can be rendered using a template using the syntax event.fields.fieldname. Hint - insert {debug} into your template see all the data passed to the template.</p>
-
-<h3>Examples</h3>
-<h4>Example of allowing Comments on Calendar events</h4>
-<p>Install the Comments module and put this in your Calendar &quot;Event Template&quot;:</p>
-<pre>{cms_module module=&#039;comments&#039; modulename=&#039;Calendar&#039; pageid=$event.event_id}</pre>
-<h3>Support</h3>
-<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
-<ul>
-<li>Discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
-<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
-<li>Lastly, you may have some success emailing the author directly.</li>  
-</ul>
-<h3>Copyright and License</h3>
-<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
-<p>This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.</p>
-<p>However, as a special exception to the GPL, this software is distributed
-as an addon module to CMS Made Simple.  You may not use this software
-in any Non GPL version of CMS Made simple, or in any version of CMS
-Made simple that does not indicate clearly and obviously in its admin 
-section that the site was built with CMS Made simple.</p>
-<p>This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
-';
-$lang['utma'] = '156861353.888709091.1253959804.1254072563.1257844615.6';
-$lang['utmz'] = '156861353.1254072563.5.3.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/projects/neoupload';
-$lang['qca'] = 'P0-2036070716-1253959804164';
-$lang['utmb'] = '156861353';
-$lang['utmc'] = '156861353';
-?>
\ No newline at end of file
+?>
