@@ -1,10 +1,18 @@
 <?php
+$lang['info_cal_filter_by'] = 'Si on recherche <em>(filtre)</em> par mots dans le titre, le d&eacute;filement de la date n&#039;est pas disponible';
+$lang['msg_nodates'] = 'Recherche du titre appliqu&eacute;e';
+$lang['title_recurring_event'] = 'C&#039;est un &eacute;v&eacute;nement r&eacute;current avec enfants';
+$lang['title_child_event'] = 'C&#039;est un enfant d&#039;un &eacute;v&eacute;nement parent r&eacute;current';
+$lang['error_somedeleted'] = 'Certains &eacute;v&eacute;nements ont &eacute;t&eacute; supprim&eacute;s. Cependant, d&#039;autres ne l&#039;ont pas &eacute;t&eacute;, &agrave; cause de permissions';
+$lang['error_nonedeleted'] = '&Agrave; cause de permissions ou d&#039;autres erreurs, aucun des &eacute;v&eacute;nements s&eacute;lectionn&eacute;s n&#039;ont &eacute;t&eacute; supprim&eacute;s';
+$lang['error_deletefailed'] = 'La suppression d&#039;&eacute;v&eacute;nement a &eacute;chou&eacute;';
+$lang['fileattachment'] = 'Fichier joint';
 $lang['prompt_general_settings'] = 'Param&egrave;tres globaux';
 $lang['prompt_editing_settings'] = 'Param&egrave;tres d&#039;&eacute;dition d&#039;&eacute;v&eacute;nements';
 $lang['prompt_feedit_settings'] = 'Param&egrave;tres d&#039;&eacute;dition de la partie publique du site (frontend)';
 $lang['prev_month'] = 'Aller au mois pr&eacute;c&eacute;dent';
 $lang['next_month'] = 'Aller au mois suivant';
-$lang['info_customfields_tab'] = 'Les champs personnalis&eacute;s peuvent &ecirc;tre r&eacute;ordonn&eacute;s en glissant / d&eacute;posant les lignes. La recherche n&#039;est possible que dans les champs texte, et seuls les zones de texte peuvent avoir des champs WYSIWYG li&eacute;s. <strong style=&quot;color: red;&quot;>Note:</strong> Les champs WYSIWYG ne seront pas affich&eacute;s pour les zones de texte sur la partie publique du site (frontend).';
+$lang['info_customfields_tab'] = 'Les champs personnalis&eacute;s peuvent &ecirc;tre r&eacute;ordonn&eacute;s en glissant / d&eacute;posant les lignes. La recherche n&#039;est possible que dans les champs texte, et seules les zones de texte peuvent avoir des champs WYSIWYG li&eacute;s. <strong style=&quot;color: red;&quot;>Note :</strong> Les champs WYSIWYG ne seront pas affich&eacute;s pour les zones de texte sur la partie publique du site (frontend).';
 $lang['msg_categories_updated'] = 'Cat&eacute;gories mises &agrave; jour';
 $lang['msg_fieldsupdated'] = 'D&eacute;finitions de champ mises &agrave; jour';
 $lang['wysiwyg'] = 'WYSIWYG';
@@ -16,7 +24,6 @@ $lang['add_category'] = 'Ajouter une cat&eacute;gorie';
 $lang['prompt_firstdayofweek'] = 'Premier jour de la semaine';
 $lang['edit_event'] = '&Eacute;diter l&#039;&eacute;v&eacute;nement';
 $lang['edit_parent_event'] = '&Eacute;diter l&#039;&eacute;v&eacute;nement parent';
-$lang['title_child_event'] = 'C&#039;est un enfant d&#039;un &eacute;v&eacute;nement parent r&eacute;current';
 $lang['select_period'] = 'P&eacute;riode';
 $lang['show_filter'] = 'Montrer le filtre';
 $lang['show_filter_applied'] = 'Montrer le filtre <em>(appliqu&eacute;)</em>';
@@ -33,7 +40,7 @@ $lang['import_completed'] = 'Importation termin&eacute;';
 $lang['num_imported'] = 'Nombre d&#039;&eacute;v&egrave;nements cr&eacute;&eacute;s: %d';
 $lang['import_lines'] = 'Nombre de lignes trait&eacute;es du fichier: %d';
 $lang['errors'] = 'Erreurs';
-$lang['error_csvfirstlineinvalidfield'] = 'Champs: %s non reconnu, et n&#039;est pas un champs personnalis&eacute;.';
+$lang['error_csvfirstlineinvalidfield'] = 'Champ : %s non reconnu, et n&#039;est pas un champ personnalis&eacute;.';
 $lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
 <ul>
   <li>General Information:
@@ -83,7 +90,6 @@ $lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
 </ul>';
 $lang['prompt_csv_file'] = 'S&eacute;lectionner le fichier d&#039;importation';
 $lang['delete'] = 'Effacer';
-$lang['cd_company'] = 'Company Directory Company';
 $lang['dflt_urlprefix'] = 'Pr&eacute;fixe d&#039;URL par d&eacute;faut pour &quot;pretty URLS&quot;';
 $lang['dflt_alldayevent'] = 'Les nouveaux &eacute;v&eacute;nements sont des &eacute;v&eacute;nements &quot;jour entier (all day)&quot; par d&eacute;faut';
 $lang['dflt_starttime'] = 'Heure de d&eacute;but par d&eacute;faut pour les nouveaux &eacute;v&eacute;nements';
@@ -98,8 +104,8 @@ $lang['help_param_myeventstemplate'] = 'Applicable uniquement pour l&#039;action
 $lang['cal_edit_event'] = 'Editer un &eacute;v&eacute;nement du calendrier';
 $lang['error_dberror'] = 'Erreur de base de donn&eacute;es';
 $lang['submit'] = 'Soumettre';
-$lang['info_sysdflt_editevent_template'] = 'Gabarit syst&egrave;me pour &amp;quot;Editer un &eacute;v&eacute;nement&amp;quot;';
-$lang['info_sysdflt_myevents_template'] = 'Gabarit syst&egrave;me pour &amp;quot;Mes &Eacute;v&eacute;nements&amp;quot;';
+$lang['info_sysdflt_editevent_template'] = 'Gabarit syst&egrave;me pour &quot;Editer un &eacute;v&eacute;nement&quot;';
+$lang['info_sysdflt_myevents_template'] = 'Gabarit syst&egrave;me pour &quot;Mes &Eacute;v&eacute;nements&quot;';
 $lang['prompt_feedit_group'] = 'Les membres de ce groupe FEU peuvent ajouter des &eacute;v&eacute;nements';
 $lang['prompt_feedit_page'] = 'Page par d&eacute;faut pour le formulaire d&#039;&eacute;dition en frontend.';
 $lang['none'] = 'Aucun';
@@ -316,7 +322,7 @@ $lang['error_fileexists'] = 'ERREUR&nbsp;: Un fichier avec le m&ecirc;me nom exi
 $lang['error_csvfilenotfound'] = 'ERREUR&nbsp;: Impossible de trouver le fichier CSV';
 $lang['error_cantopenfile'] = 'ERREUR&nbsp;: Impossible d&#039;ouvrir le fichier';
 $lang['error_categoryexists'] = 'ERREUR&nbsp;: Une cat&eacute;gorie avec le nom %s existe d&eacute;j&agrave;';
-$lang['cal_id'] = 'Id';
+$lang['cal_id'] = 'ID';
 $lang['cal_calendar'] = 'Calendrier (CG)';
 $lang['cal_default_templates'] = 'Gabarits par d&eacute;faut';
 $lang['cal_description'] = 'Ajout, &eacute;dition et suppression d&#039;&eacute;v&eacute;nements';
@@ -438,10 +444,6 @@ $lang['defaultcalendarpage'] = 'Page par d&eacute;faut qui contient le calendrie
 $lang['uploaddirectory'] = 'Dossier o&ugrave; les fichiers upload&eacute;s doivent &ecirc;tre stock&eacute;s';
 $lang['uploadfiletypes'] = 'Types de fichiers autoris&eacute;s';
 $lang['uploadunique'] = 'S&#039;assurer que les noms de fichiers soient uniques';
-$lang['thumb_width'] = 'Largeur de la vignette';
-$lang['thumb_height'] = 'Hauteur de la vignette';
-$lang['large_width'] = 'Largeur de l&#039;image en grande taille';
-$lang['large_height'] = 'Hauteur de l&#039;image en grande taille';
 $lang['cal_recur_period'] = 'R&eacute;p&eacute;tition';
 $lang['cal_recur_until'] = 'R&eacute;p&egrave;te jusqu&#039;&agrave;';
 $lang['help_template'] = '<p><b>Affiche le nom de l&#039;auteur :</b></p>
