@@ -1,4 +1,7 @@
 <?php
+$lang['prompt_general_settings'] = 'Algemene Instellingen';
+$lang['prev_month'] = 'Ga naar de vorige maand';
+$lang['next_month'] = 'Ga naar de volgende maand';
 $lang['msg_categories_updated'] = 'Categorie&euml;n zijn bijgewerkt';
 $lang['msg_fieldsupdated'] = 'Velden zijn bijgewerkt';
 $lang['wysiwyg'] = 'wysiwyg';
@@ -200,51 +203,6 @@ $lang['eventdesc-EventDeleted'] = 'Een tag die wordt aangeroepen na verwijdering
 $lang['eventdesc-CategoryAdded'] = 'Een tag die wordt aangeroepen na aanmaken van een categorie';
 $lang['eventdesc-CategoryEdited'] = 'Een tag die wordt aangeroepen na bewerking van een categorie';
 $lang['eventdesc-CategoryDeleted'] = 'Een tag die wordt aangeroepen na verwijdering van een categorie';
-$lang['eventhelp-EventAdded'] = '<p>Verzonden na toevoeging van een kalendergebeurtenis.</p>
-<h4>Parameters</h4>
-<ul>
-<li>&quot;event_title&quot; - Gebeurtenistitel</li>
-<li>&quot;event_summary&quot; - Samenvatting</li>
-<li>&quot;event_details&quot; - Gedetailleerde beschrijving</li>
-<li>&quot;event_date_start&quot; - Startdatum/tijd van gebeurtenis</li>
-<li>&quot;event_date_end&quot; - Einddatum/tijd van gebeurtenis</li>
-<li>&quot;event_created_by&quot; - De userid van de auteur</li>
-<li>&quot;event_id&quot; - De id van de gebeurtenis</li>
-</ul>';
-$lang['eventhelp-EventEdited'] = '<p>Verzonden na bewerking van een kalendergebeurtenis.</p>
-<h4>Parameters</h4>
-<ul>
-<li>&quot;event_title&quot; - Gebeurtenistitel</li>
-<li>&quot;event_summary&quot; - Samenvatting</li>
-<li>&quot;event_details&quot; - Gedetailleerde beschrijving</li>
-<li>&quot;event_date_start&quot; - Startdatum/tijd van gebeurtenis</li>
-<li>&quot;event_date_end&quot; - Einddatum/tijd van gebeurtenis</li>
-<li>&quot;event_created_by&quot; - De userid van de auteur</li>
-<li>&quot;event_id&quot; - De id van de gebeurtenis</li>
-</ul>';
-$lang['eventhelp-EventDeleted'] = '<p>Verzonden na verwijdering van een kalendergebeurtenis.</p>
-<h4>Parameters</h4>
-<ul>
-<li>&quot;event_id&quot; - Gebeurtenis-ID</li>';
-$lang['eventhelp-CategoryAdded'] = '<p>Verzonden na toevoeging van een kalendergebeurtenis.</p>
-<h4>Parameters</h4>
-<ul>
-<li>&quot;category_id - De categorie-ID</li>
-</ul>';
-$lang['eventhelp-CategoryEdited'] = '<p>Verzonden na bewerking van een kalendercategorie.</p>
-<h4>Parameters</h4>
-<ul>
-<li>&quot;category_id&quot; - De categorie-ID</li>
-<li>&quot;category_name&quot; - De categorienaam</li>
-<li>&quot;category_order&quot; - De categoriesorteervolgorde</li>
-</ul>';
-$lang['eventhelp-CategoryDeleted'] = '<p>Verzonden na verwijdering van een kalendercategorie.</p>
-<h4>Parameters</h4>
-<ul>
-<li>&quot;category_id&quot; - De categorie-ID</li>
-<li>&quot;category_name&quot; - De categorienaam</li>
-<li>&quot;category_order&quot; - De categoriesorteervolgorde</li>
-</ul>';
 $lang['error_csv_insert'] = 'Fout bij het importeren van het event uit de csv op regel %d';
 $lang['error_csvfirstlinefldnotfound'] = 'Een vereist veld: %s, kon niet worden gevonden in de eerste regel van het csv-bestand';
 $lang['error_csvinvalidfirstline'] = 'Kan geen geldige eerste regel vinden van het CSV-bestand';
@@ -311,7 +269,6 @@ $lang['cal_update'] = 'Bijwerken';
 $lang['cal_event'] = 'Gebeurtenis';
 $lang['cal_date'] = 'Datum';
 $lang['cal_summary'] = 'Samenvatting';
-$lang['cal_details'] = 'Details';
 $lang['cal_more'] = 'meer >>';
 $lang['cal_return'] = 'Terug';
 $lang['cal_to'] = 'tot';
@@ -367,7 +324,6 @@ $lang['eventdeleted'] = 'De gebeurtenis is verwijderd';
 $lang['eventupdated'] = 'De gebeurtenis is bijgewerkt';
 $lang['default_page_error'] = 'Fout: Met de toepassing van Pretty URLs moet een een standaard pagina opgeven worden, om de kalender te kunnen gebruiken.';
 $lang['time_at'] = 'om';
-$lang['type'] = 'Type';
 $lang['name'] = 'Naam';
 $lang['order'] = 'Volgorde';
 $lang['fieldadded'] = 'Veld toegevoegd';
@@ -380,16 +336,12 @@ $lang['defaultcalendarpage'] = 'Standaard pagina die de kalender bevat. Deze pag
 $lang['uploaddirectory'] = 'Map waar de ge&uuml;ploade bestanden moeten worden geplaatst';
 $lang['uploadfiletypes'] = 'Toegestane bestandstypen';
 $lang['uploadunique'] = 'Garandeer unieke bestandsnamen';
-$lang['thumb_width'] = 'Miniatuur-breedte';
-$lang['thumb_height'] = 'Miniatuur-hoogte';
-$lang['large_width'] = 'Breedte grote afbeelding';
-$lang['large_height'] = 'Hoogte grote afbeelding';
 $lang['cal_recur_period'] = 'Terugkerend';
 $lang['cal_recur_until'] = 'Terugkerend tot';
 $lang['help_template'] = '<p><b>Toon auteursnaam:</b></p>
 <code>Auteur: {$event.authorname}</code>';
-$lang['utma'] = '156861353.423918649.1382341730.1382341730.1382341730.1';
-$lang['utmz'] = '156861353.1382341730.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.1734238362.1384000844.1384000844.1384000844.1';
+$lang['utmz'] = '156861353.1384000844.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/viewtopic.php|utmcmd=referral';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
